@@ -93,6 +93,10 @@ class ResultSet extends Command {
     }
     this.opts = {
       timeout: cmdOpts.timeout,
+      autoJsonMap: connOpts.autoJsonMap,
+      arrayParenthesis: connOpts.arrayParenthesis,
+      supportBigInt:
+        cmdOpts.supportBigInt != undefined ? cmdOpts.supportBigInt : connOpts.supportBigInt,
       checkDuplicate:
         cmdOpts.checkDuplicate != undefined ? cmdOpts.checkDuplicate : connOpts.checkDuplicate,
       typeCast: cmdOpts.typeCast != undefined ? cmdOpts.typeCast : connOpts.typeCast,
@@ -100,7 +104,8 @@ class ResultSet extends Command {
       nestTables: cmdOpts.nestTables != undefined ? cmdOpts.nestTables : connOpts.nestTables,
       dateStrings: cmdOpts.dateStrings != undefined ? cmdOpts.dateStrings : connOpts.dateStrings,
       tz: cmdOpts.tz != undefined ? cmdOpts.tz : connOpts.tz,
-      localTz: cmdOpts.localTz != undefined ? cmdOpts.localTz : connOpts.localTz,
+      pipelining: connOpts.pipelining,
+      _localTz: cmdOpts.localTz != undefined ? cmdOpts.localTz : connOpts._localTz,
       namedPlaceholders:
         cmdOpts.namedPlaceholders != undefined
           ? cmdOpts.namedPlaceholders
@@ -133,8 +138,8 @@ class ResultSet extends Command {
    * @returns {*}     null or {Resultset.readResponsePacket} in case of multi-result-set
    */
   readOKPacket(packet, out, opts, info) {
-    const rs = Command.parseOkPacket(packet, out, opts, info);
-    this._rows.push(rs);
+    const okPacket = this.parseOkPacket(packet, out, opts, info);
+    this._rows.push(okPacket);
 
     if (info.status & ServerStatus.MORE_RESULTS_EXISTS) {
       this._responseIndex++;
@@ -231,8 +236,7 @@ class ResultSet extends Command {
    */
   readColumn(packet, out, opts, info) {
     if (this._columns.length !== this._columnCount) {
-      const column = ColumnDefinition.parseColumn(packet);
-      this._columns.push(column);
+      this._columns.push(new ColumnDefinition(packet, info));
     }
 
     // last column
@@ -283,7 +287,10 @@ class ResultSet extends Command {
             []
           );
           this.throwUnexpectedError(
-            'Error in results, duplicate field name `' + dupes[0] + '`',
+            'Error in results, duplicate field name `' +
+              dupes[0] +
+              '`.\n' +
+              '(see option `checkDuplicate`)',
             false,
             null,
             '42000',
@@ -307,7 +314,8 @@ class ResultSet extends Command {
                 this.tableHeader[i][0] +
                 '`.`' +
                 this.tableHeader[i][1] +
-                '`',
+                '`\n' +
+                '(see option `checkDuplicate`)',
               false,
               null,
               '42000',
@@ -396,7 +404,10 @@ class ResultSet extends Command {
           //   [ {"1": 1} ],      //rows
           //   [ColumnDefinition] //meta
           // ]
-          if (this._responseIndex === 0) this._meta = [];
+          if (!this._meta) {
+            this._meta = new Array(this._responseIndex);
+          }
+
           this._meta[this._responseIndex] = this._columns;
 
           if (info.status & ServerStatus.MORE_RESULTS_EXISTS || this.isOutParameter) {
@@ -437,13 +448,13 @@ class ResultSet extends Command {
   displaySql() {
     if (this.opts && this.initialValues) {
       if (this.sql.length > this.opts.debugLen) {
-        return 'sql: ' + this.sql.substring(0, this.opts.debugLen) + '...';
+        return this.sql.substring(0, this.opts.debugLen) + '...';
       }
 
-      let sqlMsg = 'sql: ' + this.sql + ' - parameters:';
+      let sqlMsg = this.sql + ' - parameters:';
       return this.logParameters(sqlMsg, this.initialValues);
     }
-    return 'sql: ' + this.sql + ' - parameters:[]';
+    return this.sql + ' - parameters:[]';
   }
 
   logParameters(sqlMsg, values) {
@@ -467,13 +478,20 @@ class ResultSet extends Command {
       sqlMsg += '}';
     } else {
       sqlMsg += '[';
-      for (let i = 0; i < values.length; i++) {
-        if (i !== 0) sqlMsg += ',';
-        let param = values[i];
-        sqlMsg = ResultSet.logParam(sqlMsg, param);
+      if (Array.isArray(values)) {
+        for (let i = 0; i < values.length; i++) {
+          if (i !== 0) sqlMsg += ',';
+          let param = values[i];
+          sqlMsg = ResultSet.logParam(sqlMsg, param);
+          if (sqlMsg.length > this.opts.debugLen) {
+            sqlMsg = sqlMsg.substr(0, this.opts.debugLen) + '...';
+            break;
+          }
+        }
+      } else {
+        sqlMsg = ResultSet.logParam(sqlMsg, values);
         if (sqlMsg.length > this.opts.debugLen) {
           sqlMsg = sqlMsg.substr(0, this.opts.debugLen) + '...';
-          break;
         }
       }
       sqlMsg += ']';
@@ -495,9 +513,10 @@ class ResultSet extends Command {
           "' doesn't correspond to query " +
           this.sql +
           '. Query cancelled. Check for malicious server / proxy',
+        this.sql,
         false,
         info,
-        '45034',
+        'HY000',
         Errors.ER_LOCAL_INFILE_WRONG_FILENAME
       );
 
@@ -510,10 +529,11 @@ class ResultSet extends Command {
     // this.sequenceNo = 2;
     // this.compressSequenceNo = 2;
     const stream = fs.createReadStream(fileName);
-    stream.on('error', err => {
+    stream.on('error', (err) => {
       out.writeEmptyPacket();
       const error = Errors.createError(
         'LOCAL INFILE command failed: ' + err.message,
+        this.sql,
         false,
         info,
         '22000',
@@ -523,7 +543,7 @@ class ResultSet extends Command {
       this.reject = null;
       this.resolve = null;
     });
-    stream.on('data', chunk => {
+    stream.on('data', (chunk) => {
       out.writeBuffer(chunk, 0, chunk.length);
     });
     stream.on('end', () => {
