@@ -10,29 +10,16 @@ const base = require('../base.js');
 const { assert } = require('chai');
 
 describe('cluster', function () {
-  before(function (done) {
-    if (process.env.SKYSQL) this.skip();
-    shareConn
-      .query('DROP TABLE IF EXISTS clusterInsert')
-      .then(() => {
-        shareConn
-          .query('CREATE TABLE clusterInsert(id int, nam varchar(256))')
-          .then(() => {
-            done();
-          })
-          .catch(done);
-      })
-      .catch(done);
+  before(async function () {
+    if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
+    await shareConn.query('DROP TABLE IF EXISTS clusterInsert');
+    await shareConn.query('CREATE TABLE clusterInsert(id int, nam varchar(256))');
+    await shareConn.query('FLUSH TABLES');
   });
 
   describe('promise', function () {
-    beforeEach(function (done) {
-      shareConn
-        .query('TRUNCATE TABLE clusterInsert')
-        .then(() => {
-          done();
-        })
-        .catch(done);
+    beforeEach(async function () {
+      await shareConn.query('TRUNCATE TABLE clusterInsert');
     });
 
     it('no node', function (done) {
@@ -436,8 +423,8 @@ describe('cluster', function () {
     });
 
     it('reusing node after timeout', function (done) {
-      if (process.env.SKYSQL) this.skip();
-      this.timeout(20000);
+      if (process.env.srv === 'skysql' || process.env.srv === 'skysql-ha') this.skip();
+      this.timeout(30000);
       const cl = get3NodeClusterWithProxy({ restoreNodeTimeout: 500 }, basePromise);
       const poolCluster = cl.cluster;
       const proxy = cl.proxy;
@@ -485,8 +472,12 @@ describe('cluster', function () {
     });
 
     it('server close connection during query', function (done) {
-      if (process.env.SKYSQL) this.skip();
-      if (process.env.MAXSCALE_VERSION) this.skip();
+      if (
+        process.env.srv === 'maxscale' ||
+        process.env.srv === 'skysql' ||
+        process.env.srv === 'skysql-ha'
+      )
+        this.skip();
       this.timeout(10000);
       const poolCluster = basePromise.createPoolCluster({});
 
@@ -525,7 +516,12 @@ describe('cluster', function () {
     });
 
     it('socket close connection during query', function (done) {
-      if (process.env.MAXSCALE_VERSION) this.skip();
+      if (
+        process.env.srv === 'maxscale' ||
+        process.env.srv === 'skysql' ||
+        process.env.srv === 'skysql-ha'
+      )
+        this.skip();
       if (!shareConn.info.isMariaDB() || !shareConn.info.hasMinVersion(10, 1, 2)) this.skip();
       this.timeout(10000);
       const poolCluster = basePromise.createPoolCluster({});
@@ -665,45 +661,26 @@ describe('cluster', function () {
         });
     });
 
-    it('batch on filtered', function (done) {
+    it('batch on filtered', async function () {
       this.timeout(10000);
       const poolCluster = get3NodeCluster();
       const filteredCluster = poolCluster.of(/^node[12]/);
 
-      filteredCluster
-        .query('DROP TABLE IF EXISTS filteredSimpleBatch')
-        .then(() => {
-          return filteredCluster.query(
-            'CREATE TABLE filteredSimpleBatch(id int not null primary key auto_increment, val int)'
-          );
-        })
-        .then(() => {
-          const promises = [];
-          for (let i = 0; i < 60; i++) {
-            promises.push(
-              filteredCluster.batch('INSERT INTO filteredSimpleBatch(val) values (?)', [
-                [1],
-                [2],
-                [3]
-              ])
-            );
-          }
-          Promise.all(promises)
-            .then(() => {
-              return filteredCluster.query('SELECT count(*) as nb FROM filteredSimpleBatch');
-            })
-            .then((res) => {
-              expect(res[0].nb).to.equal(180);
-              poolCluster.end().then(() => {
-                done();
-              });
-            })
-            .catch((err) => {
-              poolCluster.end().then(() => {
-                done(err);
-              });
-            });
-        });
+      await filteredCluster.query('DROP TABLE IF EXISTS filteredSimpleBatch');
+      await filteredCluster.query(
+        'CREATE TABLE filteredSimpleBatch(id int not null primary key auto_increment, val int)'
+      );
+      await filteredCluster.query('FLUSH TABLES');
+      const promises = [];
+      for (let i = 0; i < 60; i++) {
+        promises.push(
+          filteredCluster.batch('INSERT INTO filteredSimpleBatch(val) values (?)', [[1], [2], [3]])
+        );
+      }
+      await Promise.all(promises);
+      const res = await filteredCluster.query('SELECT count(*) as nb FROM filteredSimpleBatch');
+      expect(res[0].nb).to.equal(180);
+      await poolCluster.end();
     });
 
     it('batch error on filtered', function (done) {
@@ -1224,17 +1201,20 @@ describe('cluster', function () {
     const connOption1 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node1'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
     const connOption2 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node2'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
     const connOption3 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node3'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
 
     poolCluster.add('node1', connOption1);
@@ -1249,17 +1229,20 @@ describe('cluster', function () {
     const connOption1 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node1'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
     const connOption2 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node2'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
     const connOption3 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node3'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
 
     poolCluster.add('node1', connOption1);
@@ -1278,10 +1261,11 @@ describe('cluster', function () {
     });
     const proxy = new Proxy({
       port: Conf.baseConfig.port,
-      proxyPort: 4000,
       host: Conf.baseConfig.host,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
+
     const connOption2 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node2'",
       connectionLimit: 1,
@@ -1289,14 +1273,16 @@ describe('cluster', function () {
       connectTimeout: 200,
       socketTimeout: 200,
       acquireTimeout: 250,
-      port: 4000,
-      resetAfterUse: false
+      port: proxy.port(),
+      resetAfterUse: false,
+      trace: true
     });
 
     const connOption3 = Object.assign({}, Conf.baseConfig, {
       initSql: "set @node='node3'",
       connectionLimit: 1,
-      resetAfterUse: false
+      resetAfterUse: false,
+      trace: true
     });
 
     poolCluster.add('node1', connOption1);
